const Ajv = require('ajv').default;

const ValidationError = require('./validation_error');

function setup_validator(properties) {
    console.log(properties.main_schema.$id);
    return (plan) => {
        const ajv = new Ajv();
        require('ajv-merge-patch')(ajv);

        const validate = ajv.addSchema(properties.additional_schemas).compile(properties.main_schema);
        const valid = validate(plan);

        if (!valid) {
            throw new ValidationError('Error in JSON validation', validate.errors);
        }
    };
}

function get_validator(propertyFilename) {
    return (plan) => {
        const properties = require(propertyFilename);
        const validate = setup_validator(properties);
        validate(plan);
    }
}

// mixed
module.exports.validate_unassigned_plan = get_validator('./scripts/validate_mixed_input_plan');
module.exports.validate_assigned_plan = get_validator('./scripts/validate_mixed_output_plan');
module.exports.validate_job_output = get_validator('./scripts/validate_mixed_job_output');

// shift
module.exports.validate_unassigned_plan_shift = get_validator('./scripts/validate_shift_input_plan');
module.exports.validate_assigned_plan_shift = get_validator('./scripts/validate_shift_output_plan');
module.exports.validate_job_output_shift = get_validator('./scripts/validate_shift_job_output');


// floor
module.exports.validate_unassigned_plan_floor = get_validator('./scripts/validate_floor_input_plan');
module.exports.validate_assigned_plan_floor = get_validator('./scripts/validate_floor_output_plan');
module.exports.validate_job_output_floor = get_validator('./scripts/validate_floor_job_output');

// error
module.exports.ValidationError = ValidationError;